p50 calculates the median of the leiv posterior probability density. probInt calculates the shortest probability interval of the leiv posterior probability density for a given probability level.p50(p, interval, subdivisions = 100,
rel.tol = .Machine$double.eps^0.25,
abs.tol = rel.tol)probInt(p, interval, level, subdivisions = 100,
rel.tol = .Machine$double.eps^0.25,
abs.tol = rel.tol)
integrate).integrate).p50 returns a numeric scalar. probInt returns a 2-dimensional numeric vector of interval endpoints.leiv. These functions are not meant to be called by the user.leiv for general information; integrate for control parameters.